@@ -11,8 +11,6 @@ has reactor => sub {
 
 sub DESTROY { shift->close }
 
-sub new { shift->SUPER::new(handle => shift, buffer => '', timeout => 15) }
-
 sub close {
   my $self = shift;
 
@@ -43,6 +41,8 @@ sub is_writing {
   return !!length($self->{buffer}) || $self->has_subscribers('drain');
 }
 
+sub new { shift->SUPER::new(handle => shift, buffer => '', timeout => 15) }
+
 sub start {
   my $self = shift;
 
@@ -88,7 +88,7 @@ sub write {
 
   $self->{buffer} .= $chunk;
   if ($cb) { $self->once(drain => $cb) }
-  else     { return $self unless length $self->{buffer} }
+  elsif (!length $self->{buffer}) { return $self }
   $self->reactor->watch($self->{handle}, !$self->{paused}, 1)
     if $self->{handle};
 
@@ -107,7 +107,7 @@ sub _error {
   return $self->close if $! == ECONNRESET || $! == EPIPE;
 
   # Error
-  $self->emit_safe(error => $!)->close;
+  $self->emit(error => $!)->close;
 }
 
 sub _read {
@@ -129,9 +129,9 @@ sub _write {
     $self->_again;
   }
 
-  $self->emit_safe('drain') unless length $self->{buffer};
-  return if $self->is_writing;
-  return $self->close if $self->{graceful};
+  $self->emit_safe('drain') if !length $self->{buffer};
+  return                    if $self->is_writing;
+  return $self->close       if $self->{graceful};
   $self->reactor->watch($handle, !$self->{paused}, 0) if $self->{handle};
 }
 
@@ -204,7 +204,7 @@ Emitted safely once all data has been written.
     ...
   });
 
-Emitted safely if an error occurs on the stream.
+Emitted if an error occurs on the stream, fatal if unhandled.
 
 =head2 read
 
@@ -251,12 +251,6 @@ global L<Mojo::IOLoop> singleton.
 L<Mojo::IOLoop::Stream> inherits all methods from L<Mojo::EventEmitter> and
 implements the following new ones.
 
-=head2 new
-
-  my $stream = Mojo::IOLoop::Stream->new($handle);
-
-Construct a new L<Mojo::IOLoop::Stream> object.
-
 =head2 close
 
   $stream->close;
@@ -288,6 +282,12 @@ sockets.
 
 Check if stream is writing.
 
+=head2 new
+
+  my $stream = Mojo::IOLoop::Stream->new($handle);
+
+Construct a new L<Mojo::IOLoop::Stream> object.
+
 =head2 start
 
   $stream->start;
