@@ -47,7 +47,7 @@ my %MESSAGES = (
   415 => 'Unsupported Media Type',
   416 => 'Request Range Not Satisfiable',
   417 => 'Expectation Failed',
-  418 => "I'm a teapot",                       # :)
+  418 => "I'm a teapot",                       # RFC 2324 :)
   422 => 'Unprocessable Entity',               # RFC 2518 (WebDAV)
   423 => 'Locked',                             # RFC 2518 (WebDAV)
   424 => 'Failed Dependency',                  # RFC 2518 (WebDAV)
